@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -20,6 +20,10 @@ package org.apache.qpid.jms;
 
 import java.net.URI;
 
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Session;
+
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 
 public class JmsDefaultConnectionListener implements JmsConnectionListener {
@@ -43,4 +47,16 @@ public class JmsDefaultConnectionListener implements JmsConnectionListener {
     @Override
     public void onInboundMessage(JmsInboundMessageDispatch envelope) {
     }
+
+    @Override
+    public void onSessionClosed(Session session, Throwable exception) {
+    }
+
+    @Override
+    public void onConsumerClosed(MessageConsumer consumer, Throwable cause) {
+    }
+
+    @Override
+    public void onProducerClosed(MessageProducer producer, Throwable cause) {
+    }
 }
